@@ -104,6 +104,8 @@ struct BraseroBurnDialogPrivate {
 	gint64 total_size;
 	GSList *rates;
 
+	GMainLoop *loop;
+	gint wait_ready_state_id;
 	GCancellable *cancel_plugin;
 
 	gchar *initial_title;
@@ -442,7 +444,7 @@ brasero_burn_dialog_wait_for_insertion (BraseroBurnDialog *dialog,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!GTK_WIDGET_VISIBLE (dialog)) {
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	}
@@ -679,7 +681,7 @@ brasero_burn_dialog_image_error (BraseroBurn *burn,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!GTK_WIDGET_VISIBLE (dialog)) {
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	}
@@ -822,7 +824,7 @@ brasero_burn_dialog_loss_warnings_cb (BraseroBurnDialog *dialog,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!GTK_WIDGET_VISIBLE (dialog)) {
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	}
@@ -989,7 +991,7 @@ brasero_burn_dialog_eject_failure_cb (BraseroBurn *burn,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!GTK_WIDGET_VISIBLE (dialog)) {
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	}
@@ -1309,8 +1311,7 @@ brasero_burn_dialog_dummy_success_cb (BraseroBurn *burn,
 	if (!GTK_WIDGET_MAPPED (dialog)) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
-	}
-	else
+	} else
 		hide = FALSE;
 
 	g_timer_stop (priv->total_time);
@@ -1423,7 +1424,7 @@ brasero_burn_dialog_activity_stop (BraseroBurnDialog *dialog,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
+	gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (dialog)), NULL);
 
 	markup = g_strdup_printf ("<b><big>%s</big></b>", message);
 	gtk_label_set_text (GTK_LABEL (priv->header), markup);
@@ -1459,6 +1460,66 @@ brasero_burn_dialog_activity_stop (BraseroBurnDialog *dialog,
 	gtk_window_set_urgency_hint (GTK_WINDOW (dialog), TRUE);
 }
 
+static BraseroBurnResult
+brasero_burn_dialog_install_missing_cb (BraseroBurn *burn,
+					BraseroPluginErrorType type,
+					const gchar *detail,
+					gpointer user_data)
+{
+	BraseroBurnDialogPrivate *priv = BRASERO_BURN_DIALOG_PRIVATE (user_data);
+	GCancellable *cancel;
+	BraseroPK *package;
+	GdkWindow *window;
+	gboolean res;
+	int xid = 0;
+
+	gtk_widget_set_sensitive (GTK_WIDGET (user_data), FALSE);
+
+	/* Get the xid */
+	window = gtk_widget_get_window (user_data);
+	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (window));
+
+	package = brasero_pk_new ();
+	cancel = g_cancellable_new ();
+	priv->cancel_plugin = cancel;
+	switch (type) {
+		case BRASERO_PLUGIN_ERROR_MISSING_APP:
+			res = brasero_pk_install_missing_app (package, detail, xid, cancel);
+			break;
+
+		case BRASERO_PLUGIN_ERROR_MISSING_LIBRARY:
+			res = brasero_pk_install_missing_library (package, detail, xid, cancel);
+			break;
+
+		case BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN:
+			res = brasero_pk_install_gstreamer_plugin (package, detail, xid, cancel);
+			break;
+
+		default:
+			res = FALSE;
+			break;
+	}
+
+	if (package) {
+		g_object_unref (package);
+		package = NULL;
+	}
+
+	gtk_widget_set_sensitive (GTK_WIDGET (user_data), TRUE);
+	if (g_cancellable_is_cancelled (cancel)) {
+		g_object_unref (cancel);
+		return BRASERO_BURN_CANCEL;
+	}
+
+	priv->cancel_plugin = NULL;
+	g_object_unref (cancel);
+
+	if (!res)
+		return BRASERO_BURN_ERR;
+
+	return BRASERO_BURN_RETRY;
+}
+
 static BraseroBurnResult
 brasero_burn_dialog_setup_session (BraseroBurnDialog *dialog,
 				   GError **error)
@@ -1470,6 +1531,10 @@ brasero_burn_dialog_setup_session (BraseroBurnDialog *dialog,
 	brasero_burn_session_start (priv->session);
 
 	priv->burn = brasero_burn_new ();
+	g_signal_connect (priv->burn,
+			  "install-missing",
+			  G_CALLBACK (brasero_burn_dialog_install_missing_cb),
+			  dialog);
 	g_signal_connect (priv->burn,
 			  "insert-media",
 			  G_CALLBACK (brasero_burn_dialog_insert_disc_cb),
@@ -1622,7 +1687,7 @@ brasero_burn_dialog_notify_error (BraseroBurnDialog *dialog,
 	else
 		secondary = g_strdup (_("An unknown error occurred."));
 
-	if (!GTK_WIDGET_VISIBLE (dialog))
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog)))
 		gtk_widget_show (GTK_WIDGET (dialog));
 
 	message = brasero_burn_dialog_create_message (dialog,
@@ -1666,15 +1731,18 @@ brasero_burn_dialog_get_success_message (BraseroBurnDialog *dialog)
 	drive = brasero_burn_session_get_burner (priv->session);
 
 	if (brasero_track_type_get_has_stream (&priv->input)) {
-		if (BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (&priv->input))) {
-			if (priv->media & BRASERO_MEDIUM_DVD)
-				return g_strdup (_("Video DVD successfully burned"));
+		if (!brasero_drive_is_fake (drive)) {
+			if (BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (&priv->input))) {
+				if (priv->media & BRASERO_MEDIUM_DVD)
+					return g_strdup (_("Video DVD successfully burned"));
 
-			return g_strdup (_("(S)VCD successfully burned"));
+				return g_strdup (_("(S)VCD successfully burned"));
+			}
+			else
+				return g_strdup (_("Audio CD successfully burned"));
 		}
-		else
-			return g_strdup (_("Audio CD successfully burned"));
 
+		return g_strdup (_("Image successfully created"));
 	}
 	else if (brasero_track_type_get_has_medium (&priv->input)) {
 		if (!brasero_drive_is_fake (drive)) {
@@ -2116,17 +2184,18 @@ brasero_burn_dialog_record_session (BraseroBurnDialog *dialog)
 }
 
 static gboolean
-brasero_burn_dialog_wait_for_ready_state (BraseroBurnDialog *dialog)
+brasero_burn_dialog_wait_for_ready_state_cb (BraseroBurnDialog *dialog)
 {
 	BraseroBurnDialogPrivate *priv;
-	BraseroBurnResult result;
 	BraseroStatus *status;
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
 	status = brasero_status_new ();
-	result = brasero_burn_session_get_status (priv->session, status);
-	while (brasero_status_get_result (status) == BRASERO_BURN_NOT_READY) {
+	brasero_burn_session_get_status (priv->session, status);
+
+	if (brasero_status_get_result (status) == BRASERO_BURN_NOT_READY
+	||  brasero_status_get_result (status) == BRASERO_BURN_RUNNING) {
 		gdouble progress;
 		gchar *action;
 
@@ -2145,127 +2214,59 @@ brasero_burn_dialog_wait_for_ready_state (BraseroBurnDialog *dialog)
 							   progress,
 							   -1.0,
 							   priv->media);
+		g_object_unref (status);
 
-		result = brasero_burn_session_get_status (priv->session, status);
+		/* Continue */
+		return TRUE;
 	}
+
+	if (priv->loop)
+		g_main_loop_quit (priv->loop);
+
+	priv->wait_ready_state_id = 0;
+
 	g_object_unref (status);
-
-	return (result == BRASERO_BURN_OK);
-}
-
-static BraseroBurnResult
-brasero_burn_dialog_install_missing (BraseroPluginErrorType type,
-                                     const gchar *detail,
-                                     gpointer user_data)
-{
-	BraseroBurnDialogPrivate *priv = BRASERO_BURN_DIALOG_PRIVATE (user_data);
-	GCancellable *cancel;
-	BraseroPK *package;
-	gboolean res;
-	int xid = 0;
-
-	/* Get the xid */
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (user_data)->window));
-
-	package = brasero_pk_new ();
-	cancel = g_cancellable_new ();
-	priv->cancel_plugin = cancel;
-	switch (type) {
-		case BRASERO_PLUGIN_ERROR_MISSING_APP:
-			res = brasero_pk_install_missing_app (package, detail, xid, cancel);
-			break;
-
-		case BRASERO_PLUGIN_ERROR_MISSING_LIBRARY:
-			res = brasero_pk_install_missing_library (package, detail, xid, cancel);
-			break;
-
-		case BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN:
-			res = brasero_pk_install_gstreamer_plugin (package, detail, xid, cancel);
-			break;
-
-		default:
-			res = FALSE;
-			break;
-	}
-
-	if (package) {
-		g_object_unref (package);
-		package = NULL;
-	}
-
-	if (g_cancellable_is_cancelled (cancel)) {
-		g_object_unref (cancel);
-		return BRASERO_BURN_CANCEL;
-	}
-
-	priv->cancel_plugin = NULL;
-	g_object_unref (cancel);
-
-	if (!res)
-		return BRASERO_BURN_ERR;
-
-	return BRASERO_BURN_RETRY;
-}
-
-static BraseroBurnResult
-brasero_burn_dialog_list_missing (BraseroPluginErrorType type,
-                                  const gchar *detail,
-                                  gpointer user_data)
-{
-	GString *string = user_data;
-
-	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP) {
-		g_string_append_c (string, '\n');
-		/* Translators: %s is the name of a missing application */
-		g_string_append_printf (string, _("%s (application)"), detail);
-	}
-	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY) {
-		g_string_append_c (string, '\n');
-		/* Translators: %s is the name of a missing library */
-		g_string_append_printf (string, _("%s (library)"), detail);
-	}
-	else if (type == BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN) {
-		g_string_append_c (string, '\n');
-		/* Translators: %s is the name of a missing Gstreamer plugin */
-		g_string_append_printf (string, _("%s (Gstreamer plugin)"), detail);
-	}
-
-	return BRASERO_BURN_OK;
+	return FALSE;
 }
 
 static gboolean
-brasero_burn_dialog_check_plugin_errors (BraseroBurnDialog *dialog)
+brasero_burn_dialog_wait_for_ready_state (BraseroBurnDialog *dialog)
 {
 	BraseroBurnDialogPrivate *priv;
 	BraseroBurnResult result;
-	GString *string;
+	BraseroStatus *status;
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
-	gtk_widget_set_sensitive (GTK_WIDGET (dialog), FALSE);
 
-	result = brasero_session_foreach_plugin_error (priv->session,
-	                                               brasero_burn_dialog_install_missing,
-	                                               dialog);
-	if (result == BRASERO_BURN_CANCEL)
-		return FALSE;
+	status = brasero_status_new ();
+	result = brasero_burn_session_get_status (priv->session, status);
+	if (result == BRASERO_BURN_NOT_READY || result == BRASERO_BURN_RUNNING) {
+		GMainLoop *loop;
 
-	gtk_widget_set_sensitive (GTK_WIDGET (dialog), TRUE);
+		loop = g_main_loop_new (NULL, FALSE);
+		priv->loop = loop;
 
-	if (result == BRASERO_BURN_OK)
-		return TRUE;
+		priv->wait_ready_state_id = g_timeout_add_seconds (1,
+								   (GSourceFunc) brasero_burn_dialog_wait_for_ready_state_cb,
+								   dialog);
+		g_main_loop_run (loop);
 
-	string = g_string_new (_("Please install the following manually and try again:"));
-	brasero_session_foreach_plugin_error (priv->session,
-	                                      brasero_burn_dialog_list_missing,
-	                                      string);
+		priv->loop = NULL;
 
-	brasero_utils_message_dialog (GTK_WIDGET (dialog),
-	                              _("All required applications and libraries are not installed."),
-	                              string->str,
-	                              GTK_MESSAGE_ERROR);
-	g_string_free (string, TRUE);
+		if (priv->wait_ready_state_id) {
+			g_source_remove (priv->wait_ready_state_id);
+			priv->wait_ready_state_id = 0;
+		}
 
-	return FALSE;
+		g_main_loop_unref (loop);
+
+		/* Get the final status */
+		result = brasero_burn_session_get_status (priv->session, status);
+	}
+
+	g_object_unref (status);
+
+	return (result == BRASERO_BURN_OK);
 }
 
 /**
@@ -2293,14 +2294,13 @@ brasero_burn_dialog_run (BraseroBurnDialog *dialog,
 	brasero_burn_session_get_input_type (session, &priv->input);
 	brasero_burn_dialog_update_media (dialog);
 
+	/* show it early */
+	gtk_widget_show (GTK_WIDGET (dialog));
+
 	/* wait for ready state */
 	if (!brasero_burn_dialog_wait_for_ready_state (dialog))
 		return FALSE;
 
-	/* Make sure all plugins are ready */
-	if (!brasero_burn_dialog_check_plugin_errors (dialog))
-		return FALSE;
-
 	/* disable autoconfiguration */
 	if (BRASERO_IS_SESSION_CFG (priv->session))
 		brasero_session_cfg_disable (BRASERO_SESSION_CFG (priv->session));
@@ -2312,7 +2312,7 @@ brasero_burn_dialog_run (BraseroBurnDialog *dialog,
 	priv->initial_icon = g_strdup (gtk_window_get_icon_name (GTK_WINDOW (dialog)));
 
 	do {
-		if (!GTK_WIDGET_VISIBLE (dialog))
+		if (!gtk_widget_get_visible (GTK_WIDGET (dialog)))
 			gtk_widget_show (GTK_WIDGET (dialog));
 
 		result = brasero_burn_dialog_record_session (dialog);
@@ -2395,6 +2395,11 @@ brasero_burn_dialog_cancel (BraseroBurnDialog *dialog,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
+	if (priv->loop) {
+		g_main_loop_quit (priv->loop);
+		return TRUE;
+	}
+
 	if (!priv->burn)
 		return TRUE;
 
@@ -2550,6 +2555,11 @@ brasero_burn_dialog_finalize (GObject * object)
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (object);
 
+	if (priv->wait_ready_state_id) {
+		g_source_remove (priv->wait_ready_state_id);
+		priv->wait_ready_state_id = 0;
+	}
+
 	if (priv->cancel_plugin) {
 		g_cancellable_cancel (priv->cancel_plugin);
 		priv->cancel_plugin = NULL;
