@@ -136,6 +136,7 @@ typedef enum {
 	ACTION_CHANGED_SIGNAL,
 	DUMMY_SUCCESS_SIGNAL,
 	EJECT_FAILURE_SIGNAL,
+	INSTALL_MISSING_SIGNAL,
 	LAST_SIGNAL
 } BraseroBurnSignalType;
 
@@ -814,11 +815,15 @@ brasero_burn_lock_dest_media (BraseroBurn *burn,
 		goto end;
 	}
 
-	/* make sure that media is supported and can be written to */
-	/* make sure that media is supported.
-	 * Since we did not check the flags and
-	 * and since they might change check if the
-	 * session is supported without the flags */
+	/* Make sure that media is supported and
+	 * can be written to */
+
+	/* NOTE: Since we did not check the flags
+	 * and since they might change, check if the
+	 * session is supported without the flags.
+	 * We use quite a strict checking though as
+	 * from now on we require plugins to be
+	 * ready. */
 	result = brasero_burn_session_can_burn (priv->session, FALSE);
 	if (result != BRASERO_BURN_OK) {
 		BRASERO_BURN_LOG ("Inserted media is not supported");
@@ -1655,6 +1660,66 @@ start:
 	return BRASERO_BURN_ERR;
 }
 
+static BraseroBurnResult
+brasero_burn_install_missing (BraseroPluginErrorType error,
+			      const gchar *details,
+			      gpointer user_data)
+{
+	GValue instance_and_params [3];
+	GValue return_value;
+
+	instance_and_params [0].g_type = 0;
+	g_value_init (instance_and_params, G_TYPE_FROM_INSTANCE (user_data));
+	g_value_set_instance (instance_and_params, user_data);
+	
+	instance_and_params [1].g_type = 0;
+	g_value_init (instance_and_params + 1, G_TYPE_INT);
+	g_value_set_int (instance_and_params + 1, error);
+
+	instance_and_params [2].g_type = 0;
+	g_value_init (instance_and_params + 2, G_TYPE_STRING);
+	g_value_set_string (instance_and_params + 2, details);
+
+	return_value.g_type = 0;
+	g_value_init (&return_value, G_TYPE_INT);
+	g_value_set_int (&return_value, BRASERO_BURN_ERROR);
+
+	g_signal_emitv (instance_and_params,
+			brasero_burn_signals [INSTALL_MISSING_SIGNAL],
+			0,
+			&return_value);
+
+	g_value_unset (instance_and_params);
+
+	return g_value_get_int (&return_value);		       
+}
+
+static BraseroBurnResult
+brasero_burn_list_missing (BraseroPluginErrorType type,
+			   const gchar *detail,
+			   gpointer user_data)
+{
+	GString *string = user_data;
+
+	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP) {
+		g_string_append_c (string, '\n');
+		/* Translators: %s is the name of a missing application */
+		g_string_append_printf (string, _("%s (application)"), detail);
+	}
+	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY) {
+		g_string_append_c (string, '\n');
+		/* Translators: %s is the name of a missing library */
+		g_string_append_printf (string, _("%s (library)"), detail);
+	}
+	else if (type == BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN) {
+		g_string_append_c (string, '\n');
+		/* Translators: %s is the name of a missing Gstreamer plugin */
+		g_string_append_printf (string, _("%s (Gstreamer plugin)"), detail);
+	}
+
+	return BRASERO_BURN_OK;
+}
+
 static BraseroBurnResult
 brasero_burn_check_session_consistency (BraseroBurn *burn,
                                         BraseroTrackType *output,
@@ -1686,6 +1751,34 @@ brasero_burn_check_session_consistency (BraseroBurn *burn,
 		return BRASERO_BURN_ERR;
 	}
 
+	/* Check missing applications/GStreamer plugins.
+	 * This is the best place. */
+	result = brasero_burn_session_can_burn (priv->session, FALSE);
+	if (result != BRASERO_BURN_OK)
+		return result;
+
+	result = brasero_session_foreach_plugin_error (priv->session,
+	                                               brasero_burn_install_missing,
+	                                               burn);
+	if (result != BRASERO_BURN_OK) {
+		if (result != BRASERO_BURN_CANCEL) {
+			GString *string;
+
+			string = g_string_new (_("Please install the following required applications and libraries manually and try again:"));
+			brasero_session_foreach_plugin_error (priv->session,
+			                                      brasero_burn_list_missing,
+	        			                      string);
+			g_set_error (error,
+				     BRASERO_BURN_ERROR,
+				     BRASERO_BURN_ERROR_MISSING_APP_AND_PLUGIN,
+				     string->str);
+
+			g_string_free (string, TRUE);
+		}
+
+		return BRASERO_BURN_ERR;
+	}
+
 	/* No need to check if a burner was set as this
 	 * is done when locking. */
 
@@ -1698,7 +1791,7 @@ brasero_burn_check_session_consistency (BraseroBurn *burn,
 							      &supported,
 							      &compulsory);
 	else
-		result = brasero_caps_session_get_file_flags (input,
+		result = brasero_caps_session_get_image_flags (input,
 		                                              output,
 		                                              &supported,
 		                                              &compulsory);
@@ -1726,7 +1819,7 @@ brasero_burn_check_session_consistency (BraseroBurn *burn,
 									      &supported,
 									      &compulsory);
 			else
-				result = brasero_caps_session_get_file_flags (input,
+				result = brasero_caps_session_get_image_flags (input,
 									      output,
 									      &supported,
 									      &compulsory);
@@ -1796,35 +1889,15 @@ brasero_burn_check_data_loss (BraseroBurn *burn,
 	input = brasero_track_type_new ();
 	brasero_burn_session_get_input_type (priv->session, input);
 
-	if (flags & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) {
-		/* There is an error if APPEND was set since this disc is not
-		 * supported without a prior blanking. */
-		
-		/* we warn the user is going to lose data even if in the case of
-		 * DVD+/-RW we don't really blank the disc we rather overwrite */
-		result = brasero_burn_emit_signal (burn,
-						   WARN_DATA_LOSS_SIGNAL,
-						   BRASERO_BURN_CANCEL);
-		if (result == BRASERO_BURN_NEED_RELOAD)
-			goto reload;
+	if (media & (BRASERO_MEDIUM_HAS_DATA|BRASERO_MEDIUM_HAS_AUDIO)) {
+		if (flags & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE) {
+			/* There is an error if APPEND was set since this disc is not
+			 * supported without a prior blanking. */
 
-		if (result != BRASERO_BURN_OK) {
-			brasero_track_type_free (input);
-			return result;
-		}
-	}
-	else if (media & (BRASERO_MEDIUM_HAS_DATA|BRASERO_MEDIUM_HAS_AUDIO)) {
-		/* A few special warnings for the discs with data/audio on them
-		 * that don't need prior blanking or can't be blanked */
-		if ((media & BRASERO_MEDIUM_CD)
-		&&  brasero_track_type_get_has_stream (input)
-		&& !BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (input))) {
-			/* We'd rather blank and rewrite a disc rather than
-			 * append audio to appendable disc. That's because audio
-			 * tracks have little chance to be readable by common CD
-			 * player as last tracks */
+			/* we warn the user is going to lose data even if in the case of
+			 * DVD+/-RW we don't really blank the disc we rather overwrite */
 			result = brasero_burn_emit_signal (burn,
-							   WARN_AUDIO_TO_APPENDABLE_SIGNAL,
+							   WARN_DATA_LOSS_SIGNAL,
 							   BRASERO_BURN_CANCEL);
 			if (result == BRASERO_BURN_NEED_RELOAD)
 				goto reload;
@@ -1834,37 +1907,59 @@ brasero_burn_check_data_loss (BraseroBurn *burn,
 				return result;
 			}
 		}
+		else {
+			/* A few special warnings for the discs with data/audio on them
+			 * that don't need prior blanking or can't be blanked */
+			if ((media & BRASERO_MEDIUM_CD)
+			&&  brasero_track_type_get_has_stream (input)
+			&& !BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (input))) {
+				/* We'd rather blank and rewrite a disc rather than
+				 * append audio to appendable disc. That's because audio
+				 * tracks have little chance to be readable by common CD
+				 * player as last tracks */
+				result = brasero_burn_emit_signal (burn,
+								   WARN_AUDIO_TO_APPENDABLE_SIGNAL,
+								   BRASERO_BURN_CANCEL);
+				if (result == BRASERO_BURN_NEED_RELOAD)
+					goto reload;
 
-		/* NOTE: if input is AUDIO we don't care since the OS
-		 * will load the last session of DATA anyway */
-		if ((media & BRASERO_MEDIUM_HAS_DATA)
-		&&   brasero_track_type_get_has_data (input)
-		&& !(flags & BRASERO_BURN_FLAG_MERGE)) {
-			/* warn the users that their previous data
-			 * session (s) will not be mounted by default by
-			 * the OS and that it'll be invisible */
-			result = brasero_burn_emit_signal (burn,
-							   WARN_PREVIOUS_SESSION_LOSS_SIGNAL,
-							   BRASERO_BURN_CANCEL);
-
-			if (result == BRASERO_BURN_RETRY) {
-				/* Wipe out the current flags,
-				 * Add a new one 
-				 * Recheck the result */
-				brasero_burn_session_pop_settings (priv->session);
-				brasero_burn_session_push_settings (priv->session);
-				brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_MERGE);
-				result = brasero_burn_check_session_consistency (burn, NULL, error);
-				if (result != BRASERO_BURN_OK)
+				if (result != BRASERO_BURN_OK) {
+					brasero_track_type_free (input);
 					return result;
+				}
 			}
 
-			if (result == BRASERO_BURN_NEED_RELOAD)
-				goto reload;
+			/* NOTE: if input is AUDIO we don't care since the OS
+			 * will load the last session of DATA anyway */
+			if ((media & BRASERO_MEDIUM_HAS_DATA)
+			&&   brasero_track_type_get_has_data (input)
+			&& !(flags & BRASERO_BURN_FLAG_MERGE)) {
+				/* warn the users that their previous data
+				 * session (s) will not be mounted by default by
+				 * the OS and that it'll be invisible */
+				result = brasero_burn_emit_signal (burn,
+								   WARN_PREVIOUS_SESSION_LOSS_SIGNAL,
+								   BRASERO_BURN_CANCEL);
 
-			if (result != BRASERO_BURN_OK) {
-				brasero_track_type_free (input);
-				return result;
+				if (result == BRASERO_BURN_RETRY) {
+					/* Wipe out the current flags,
+					 * Add a new one 
+					 * Recheck the result */
+					brasero_burn_session_pop_settings (priv->session);
+					brasero_burn_session_push_settings (priv->session);
+					brasero_burn_session_add_flag (priv->session, BRASERO_BURN_FLAG_MERGE);
+					result = brasero_burn_check_session_consistency (burn, NULL, error);
+					if (result != BRASERO_BURN_OK)
+						return result;
+				}
+
+				if (result == BRASERO_BURN_NEED_RELOAD)
+					goto reload;
+
+				if (result != BRASERO_BURN_OK) {
+					brasero_track_type_free (input);
+					return result;
+				}
 			}
 		}
 	}
@@ -3055,6 +3150,17 @@ brasero_burn_class_init (BraseroBurnClass *klass)
 			      brasero_marshal_INT__OBJECT,
 			      G_TYPE_INT, 1,
 		              BRASERO_TYPE_DRIVE);
+        brasero_burn_signals [INSTALL_MISSING_SIGNAL] =
+		g_signal_new ("install_missing",
+			      G_TYPE_FROM_CLASS (klass),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (BraseroBurnClass,
+					       install_missing),
+			      NULL, NULL,
+			      brasero_marshal_INT__INT_STRING,
+			      G_TYPE_INT, 2,
+		              G_TYPE_INT,
+			      G_TYPE_STRING);
 }
 
 static void
