@@ -80,7 +80,7 @@ struct _BraseroSessionSetting {
 	/**
 	 * Used when outputting an image instead of burning
 	 */
-	BraseroTrackType output;
+	BraseroImageFormat format;
 	gchar *image;
 	gchar *toc;
 
@@ -112,6 +112,8 @@ struct _BraseroBurnSessionPrivate {
 
 	GSList *tracks;
 	GSList *pile_tracks;
+
+	guint strict_checks:1;
 };
 typedef struct _BraseroBurnSessionPrivate BraseroBurnSessionPrivate;
 
@@ -246,12 +248,63 @@ brasero_burn_session_free_tracks (BraseroBurnSession *self)
 	}
 }
 
+/**
+ * brasero_burn_session_set_strict_support:
+ * @session: a #BraseroBurnSession.
+ * @flags: a #BraseroSessionCheckFlags
+ *
+ * For the following functions:
+ * brasero_burn_session_supported ()
+ * brasero_burn_session_input_supported ()
+ * brasero_burn_session_output_supported ()
+ * brasero_burn_session_can_blank ()
+ * this function sets whether these functions will
+ * ignore the plugins with errors (%TRUE).
+ */
+
+void
+brasero_burn_session_set_strict_support (BraseroBurnSession *session,
+                                         gboolean strict_checks)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_if_fail (BRASERO_IS_BURN_SESSION (session));
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (session);
+	priv->strict_checks = strict_checks;
+}
+
+/**
+ * brasero_burn_session_get_strict_support:
+ * @session: a #BraseroBurnSession.
+ *
+ * For the following functions:
+ * brasero_burn_session_can_burn ()
+ * brasero_burn_session_input_supported ()
+ * brasero_burn_session_output_supported ()
+ * brasero_burn_session_can_blank ()
+ * this function gets whether the checks will 
+ * ignore the plugins with errors (return %TRUE).
+ *
+ * Returns:  #gboolean
+ */
+
+gboolean
+brasero_burn_session_get_strict_support (BraseroBurnSession *session)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (session), FALSE);
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (session);
+	return priv->strict_checks;
+}
 
 /**
  * brasero_burn_session_add_track:
- * @session: a #BraseroBurnSession
- * @new_track: a #BraseroTrack or NULL
- * @sibling: a #BraseroTrack or NULL
+ * @session: a #BraseroBurnSession.
+ * @new_track: (allow-none): a #BraseroTrack or NULL.
+ * @sibling: (allow-none): a #BraseroTrack or NULL.
  *
  * Inserts a new track after @sibling or appended if @sibling is NULL. If @track is NULL then all tracks
  * already in @session will be removed.
@@ -330,9 +383,9 @@ brasero_burn_session_add_track (BraseroBurnSession *self,
 
 /**
  * brasero_burn_session_move_track:
- * @session: a #BraseroBurnSession
- * @track: a #BraseroTrack
- * @sibling: a #BraseroTrack or NULL
+ * @session: a #BraseroBurnSession.
+ * @track: a #BraseroTrack.
+ * @sibling: (allow-none): a #BraseroTrack or NULL.
  *
  * Moves @track after @sibling; if @sibling is NULL then it is appended.
  *
@@ -424,7 +477,8 @@ brasero_burn_session_remove_track (BraseroBurnSession *session,
  *
  * Returns the list of #BraseroTrack added to @session.
  *
- * Return value: a #GSList or #BraseroTrack object. Do not unref the objects in the list nor destroy the list.
+ * Return value: (element-type BraseroBurn.Track) (transfer none): a #GSList or #BraseroTrack object. Do not unref the objects in the list nor destroy the list.
+ *
  **/
 
 GSList *
@@ -457,6 +511,7 @@ brasero_burn_session_get_status (BraseroBurnSession *session,
 				 BraseroStatus *status)
 {
 	BraseroBurnSessionPrivate *priv;
+	BraseroMediumMonitor *monitor;
 	BraseroStatus *track_status;
 	gdouble num_tracks = 0.0;
 	gdouble done = -1.0;
@@ -470,6 +525,17 @@ brasero_burn_session_get_status (BraseroBurnSession *session,
 		return BRASERO_BURN_ERR;
 
 	track_status = brasero_status_new ();
+
+	/* Make sure that libbrasero-media is initialized */
+	monitor = brasero_medium_monitor_get_default ();
+	if (brasero_medium_monitor_is_probing (monitor)) {
+		BRASERO_BURN_LOG ("Media library not ready yet");
+		brasero_status_set_not_ready (status, -1, NULL);
+		g_object_unref (monitor);
+		return BRASERO_BURN_NOT_READY;
+	}
+	g_object_unref (monitor);
+
 	for (iter = priv->tracks; iter; iter = iter->next) {
 		BraseroTrack *track;
 		BraseroBurnResult result;
@@ -478,17 +544,17 @@ brasero_burn_session_get_status (BraseroBurnSession *session,
 		result = brasero_track_get_status (track, track_status);
 		num_tracks ++;
 
-		if (result == BRASERO_BURN_NOT_READY)
+		if (result == BRASERO_BURN_NOT_READY || result == BRASERO_BURN_RUNNING)
 			not_ready ++;
 		else if (result != BRASERO_BURN_OK) {
-			brasero_status_free (track_status);
+			g_object_unref (track_status);
 			return brasero_track_get_status (track, status);
 		}
 
 		if (brasero_status_get_progress (track_status) != -1.0)
 			done += brasero_status_get_progress (track_status);
 	}
-	brasero_status_free (track_status);
+	g_object_unref (track_status);
 
 	if (not_ready > 0) {
 		if (status) {
@@ -705,7 +771,7 @@ brasero_burn_session_set_burner (BraseroBurnSession *self,
  *
  * Returns the #BraseroDrive that should be used to burn the session contents.
  *
- * Return value: a #BraseroDrive or NULL. Do not unref after use.
+ * Return value: (transfer none) (allow-none): a #BraseroDrive or NULL. Do not unref after use.
  **/
 
 BraseroDrive *
@@ -808,12 +874,12 @@ brasero_burn_session_get_output_type (BraseroBurnSession *self,
 		return BRASERO_BURN_NOT_READY;
 
 	if (brasero_drive_is_fake (priv->settings->burner)) {
-		output->type = BRASERO_TRACK_TYPE_IMAGE;
-		output->subtype.img_format = brasero_burn_session_get_output_format (self);
+		brasero_track_type_set_has_image (output);
+		brasero_track_type_set_image_format (output, brasero_burn_session_get_output_format (self));
 	}
 	else {
-		output->type = BRASERO_TRACK_TYPE_DISC;
-		output->subtype.media = brasero_medium_get_status (brasero_drive_get_medium (priv->settings->burner));
+		brasero_track_type_set_has_medium (output);
+		brasero_track_type_set_medium_type (output, brasero_medium_get_status (brasero_drive_get_medium (priv->settings->burner)));
 	}
 
 	return BRASERO_BURN_OK;
@@ -821,9 +887,9 @@ brasero_burn_session_get_output_type (BraseroBurnSession *self,
 
 /**
  * brasero_burn_session_get_output:
- * @session: a #BraseroBurnSession
- * @image: a #gchar or NULL
- * @toc: a #gchar or NULL
+ * @session: a #BraseroBurnSession.
+ * @image: (allow-none) (out): a #gchar to store the image path or NULL.
+ * @toc: (allow-none) (out): a #gchar to store the toc path or NULL.
  *
  * When the contents of @session should be written to a
  * file then this function returns the image path (and if
@@ -946,7 +1012,7 @@ brasero_burn_session_get_output_format_real (BraseroBurnSession *self)
 	BraseroBurnSessionPrivate *priv;
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
-	return brasero_track_type_get_image_format (&(priv->settings->output));
+	return priv->settings->format;
 }
 
 /**
@@ -980,8 +1046,7 @@ brasero_burn_session_set_image_output_real (BraseroBurnSession *self,
 	else
 		priv->settings->toc = NULL;
 
-	brasero_track_type_set_has_image (&(priv->settings->output));
-	brasero_track_type_set_image_format (&(priv->settings->output),  format);
+	priv->settings->format = format;
 }
 
 static void
@@ -1011,8 +1076,7 @@ brasero_burn_session_set_output_image_real (BraseroBurnSession *self,
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
-	if (brasero_track_type_get_has_image (&(priv->settings->output))
-	&& brasero_track_type_get_image_format (&(priv->settings->output)) == format
+	if (priv->settings->format == format
 	&&  BRASERO_STR_EQUAL (image, priv->settings->image)
 	&&  BRASERO_STR_EQUAL (toc, priv->settings->toc)) {
 		if (!BRASERO_BURN_SESSION_WRITE_TO_FILE (priv))
@@ -1077,10 +1141,10 @@ brasero_burn_session_set_image_output_format (BraseroBurnSession *self,
 
 /**
  * brasero_burn_session_set_image_output_full:
- * @session: a #BraseroBurnSession
- * @format: a #BraseroImageFormat
- * @image: a #gchar or NULL
- * @toc: a #gchar or NULL
+ * @session: a #BraseroBurnSession.
+ * @format: a #BraseroImageFormat.
+ * @image: (allow-none): a #gchar or NULL.
+ * @toc: (allow-none): a #gchar or NULL.
  *
  * When the contents of @session should be written to a
  * file, this function sets the different parameters of this
@@ -1511,7 +1575,7 @@ brasero_burn_session_get_flags (BraseroBurnSession *self)
 /**
  * brasero_burn_session_set_label:
  * @session: a #BraseroBurnSession
- * @label: a #gchar
+ * @label: (allow-none): a #gchar or %NULL
  *
  * Sets the label for @session.
  *
