@@ -44,11 +44,11 @@ G_BEGIN_DECLS
 #define LIBBRASERO_MEDIA_VERSION_MINOR						\
 	29
 #define LIBBRASERO_MEDIA_VERSION_MICRO						\
-	1
+	3
 #define LIBBRASERO_MEDIA_AGE							\
 	202
 #define LIBBRASERO_MEDIA_INSTALL							\
-	"/usr/local"
+	"/gnome/usr"
 
 /**
  * To start and stop the library
