@@ -1,3 +1,5 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+
 /***************************************************************************
  *            audio-disc.c
  *
@@ -236,6 +238,9 @@ brasero_audio_disc_is_empty (BraseroDisc *disc)
 	GtkTreeModel *model;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (BRASERO_AUDIO_DISC (disc)->priv->tree));
+	if (!model)
+		return TRUE;
+
 	return gtk_tree_model_iter_n_children (model, NULL) != 0;
 }
 
@@ -530,7 +535,7 @@ brasero_audio_disc_reset_real (BraseroAudioDisc *disc)
 	}
 
 	if (disc->priv->message)
-		brasero_notify_message_remove (BRASERO_NOTIFY (disc->priv->message), BRASERO_AUDIO_DISC_CONTEXT);
+		brasero_notify_message_remove (disc->priv->message, BRASERO_AUDIO_DISC_CONTEXT);
 }
 
 static void
@@ -841,7 +846,7 @@ brasero_audio_disc_wav_dts_file_dialog (BraseroAudioDisc *disc)
 	BraseroSessionCfg *session;
 	GtkTreeModel *model;
 
-	if (brasero_notify_get_message_by_context_id (BRASERO_NOTIFY (disc->priv->message),
+	if (brasero_notify_get_message_by_context_id (disc->priv->message,
 	                                              BRASERO_AUDIO_DISC_CONTEXT))
 		return;
 
@@ -852,7 +857,7 @@ brasero_audio_disc_wav_dts_file_dialog (BraseroAudioDisc *disc)
 	                                  BRASERO_SESSION_STREAM_AUDIO_FORMAT,
 	                                  BRASERO_AUDIO_FORMAT_RAW);
 
-	message = brasero_notify_message_add (BRASERO_NOTIFY (disc->priv->message),
+	message = brasero_notify_message_add (disc->priv->message,
 					      _("Do you want to create an audio CD with DTS tracks?"),
 					      _("Some of the selected songs are suitable for creating DTS tracks."
 					        "\nThis type of audio CD track provides a higher quality of sound but can only be played by specific digital players."
@@ -860,20 +865,17 @@ brasero_audio_disc_wav_dts_file_dialog (BraseroAudioDisc *disc)
 					      0,
 					      BRASERO_AUDIO_DISC_CONTEXT);
 
-	brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message),
-					GTK_MESSAGE_INFO);
+	gtk_info_bar_set_message_type (GTK_INFO_BAR (message), GTK_MESSAGE_INFO);
 
-	brasero_notify_button_add (BRASERO_NOTIFY (disc->priv->message),
-				   BRASERO_DISC_MESSAGE (message),
-				   _("Create _Regular Tracks"),
-				   _("Click here to burn all songs as regular tracks"),
-				   GTK_RESPONSE_NO);
+	gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+							    						  _("Create _Regular Tracks"),
+							    						  GTK_RESPONSE_NO),
+					     	     _("Click here to burn all songs as regular tracks"));
 
-	brasero_notify_button_add (BRASERO_NOTIFY (disc->priv->message),
-				   BRASERO_DISC_MESSAGE (message),
-				   _("Create _DTS Tracks"),
-				   _("Click here to burn all suitable songs as DTS tracks"),
-				   GTK_RESPONSE_OK);
+	gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+							    						  _("Create _DTS Tracks"),
+							    						  GTK_RESPONSE_OK),
+					     	     _("Click here to burn all suitable songs as DTS tracks"));
 
 	g_signal_connect (BRASERO_DISC_MESSAGE (message),
 			  "response",
@@ -891,7 +893,7 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 	BraseroStatus *status;
 	gboolean should_use_dts;
 
-	if (!GTK_WIDGET (self)->window)
+	if (!gtk_widget_get_window (GTK_WIDGET (self)))
 		return;
 
 	/* make sure all tracks have video */
@@ -924,6 +926,7 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 							   BRASERO_TRACK (track));
 
 			error = brasero_status_get_error (status);
+			g_print ("ERR %i\n", error->code);
 			if (!error)
 				brasero_audio_disc_file_type_error_dialog (self, uri);
 			else if (error->code == BRASERO_BURN_ERROR_FILE_FOLDER) {
@@ -953,7 +956,7 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 			continue;
 		}
 
-		if (result == BRASERO_BURN_NOT_READY) {
+		if (result == BRASERO_BURN_NOT_READY || result == BRASERO_BURN_RUNNING) {
 			notready = TRUE;
 			continue;
 		}
@@ -1610,8 +1613,8 @@ brasero_audio_disc_edit_single_song_properties (BraseroAudioDisc *disc,
         /* information about the track */
         gtk_tree_model_get_iter (model, &iter, treepath);
         gtk_tree_model_get (model, &iter,
-                                         BRASERO_VIDEO_TREE_MODEL_INDEX_NUM, &track_num,
-                                         -1);
+                            BRASERO_VIDEO_TREE_MODEL_INDEX_NUM, &track_num,
+                            -1);
         brasero_track_stream_get_length (BRASERO_TRACK_STREAM (track), &length);
 
 	/* set up dialog */
@@ -1652,9 +1655,9 @@ brasero_audio_disc_edit_single_song_properties (BraseroAudioDisc *disc,
 					   &gap);
 
 	brasero_track_stream_set_boundaries (BRASERO_TRACK_STREAM (track),
-                                                                      start,
-                                                                      end,
-                                                                      BRASERO_SECTORS_TO_DURATION (gap));
+                                             start,
+                                             end,
+                                             gap);
 
 	if (title)
 		brasero_track_tag_add_string (BRASERO_TRACK (track),
