@@ -253,7 +253,7 @@ brasero_data_disc_import_session_cb (GtkToggleAction *action,
 	if (!medium)
 		return;
 
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_MULTISESSION);
+	brasero_notify_message_remove (priv->message, BRASERO_NOTIFY_CONTEXT_MULTISESSION);
 	res = brasero_data_disc_import_session (self,
 						medium,
 						gtk_toggle_action_get_active (action));
@@ -529,7 +529,7 @@ brasero_data_disc_project_loading_cb (BraseroTrackDataCfg *project,
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
 	priv->loading = TRUE;
 
-	message = brasero_notify_get_message_by_context_id (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_LOADING);
+	message = brasero_notify_get_message_by_context_id (priv->message, BRASERO_NOTIFY_CONTEXT_LOADING);
 	if (!message)
 		return;
 
@@ -548,7 +548,7 @@ brasero_data_disc_project_loaded_cb (BraseroTrackDataCfg *project,
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
 	priv->loading = FALSE;
 
-	message = brasero_notify_get_message_by_context_id (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_LOADING);
+	message = brasero_notify_get_message_by_context_id (priv->message, BRASERO_NOTIFY_CONTEXT_LOADING);
 	if (!message)
 		return;
 
@@ -560,18 +560,18 @@ brasero_data_disc_project_loaded_cb (BraseroTrackDataCfg *project,
 		brasero_disc_message_set_secondary (BRASERO_DISC_MESSAGE (message),
 						    _("Discard the current modified project"));
 
-		brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message),GTK_STOCK_DIALOG_WARNING);
+		gtk_info_bar_set_message_type (GTK_INFO_BAR (message), GTK_MESSAGE_WARNING);
+
 		brasero_disc_message_set_progress_active (BRASERO_DISC_MESSAGE (message), FALSE);
-		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
-					   BRASERO_DISC_MESSAGE (message),
-					   _("_Discard"),
-					   _("Discard the current modified project"),
-					   GTK_RESPONSE_CANCEL);
-		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
-					   BRASERO_DISC_MESSAGE (message),
-					   _("_Continue"),
-					   _("Continue with the current modified project"),
-					   GTK_RESPONSE_OK);
+		gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+								      _("_Discard"),
+							    	      GTK_RESPONSE_CANCEL),
+					     _("Discard the current modified project"));
+
+		gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+								      _("_Continue"),
+							    	      GTK_RESPONSE_OK),
+					     _("Continue with the current modified project"));
 
 		brasero_disc_message_add_errors (BRASERO_DISC_MESSAGE (message),
 						 priv->load_errors);
@@ -591,10 +591,8 @@ static gboolean
 brasero_data_disc_launch_image (gpointer data)
 {
 	gchar *uri = data;
-	GtkWidget *manager;
 
-	manager = brasero_app_get_project_manager (brasero_app_get_default ());
-	brasero_project_manager_iso (BRASERO_PROJECT_MANAGER (manager), uri);
+	brasero_app_image (brasero_app_get_default (), NULL, uri, FALSE);
 	g_free (uri);
 
 	return FALSE;
@@ -1074,7 +1072,7 @@ brasero_data_disc_remove_available_medium (BraseroDataDisc *self,
 	action = gtk_action_group_get_action (priv->import_group, action_name);
 	g_free (action_name);
 
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_MULTISESSION);
+	brasero_notify_message_remove (priv->message, BRASERO_NOTIFY_CONTEXT_MULTISESSION);
 
 	merge_id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (action), BRASERO_DATA_DISC_MERGE_ID));
 	gtk_ui_manager_remove_ui (priv->manager, merge_id);
@@ -1109,7 +1107,7 @@ brasero_data_disc_session_available_cb (BraseroTrackDataCfg *session,
 		volume_name = brasero_volume_get_name (BRASERO_VOLUME (medium));
 		/* Translators: %s is the name of the volume to import */
 		string = g_strdup_printf (_("Do you want to import the session from \"%s\"?"), volume_name);
-		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
+		message = brasero_notify_message_add (priv->message,
 						      string,
 						      _("That way, old files from previous sessions will be usable after burning."),
 						      10000,
@@ -1117,14 +1115,11 @@ brasero_data_disc_session_available_cb (BraseroTrackDataCfg *session,
 		g_free (volume_name);
 		g_free (string);
 
-		brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message),
-						GTK_STOCK_DIALOG_INFO);
-
-		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
-					   BRASERO_DISC_MESSAGE (message),
-					   _("I_mport Session"),
-					   _("Click here to import its contents"),
-					   GTK_RESPONSE_OK);
+		gtk_info_bar_set_message_type (GTK_INFO_BAR (message), GTK_MESSAGE_INFO);
+		gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+								      _("I_mport Session"),
+							    	      GTK_RESPONSE_OK),
+					     _("Click here to import its contents"));
 
 		/* no need to ref the medium since its removal would cause the
 		 * hiding of the message it's associated with */
@@ -1196,9 +1191,9 @@ brasero_data_disc_clear (BraseroDisc *disc)
 
 	priv->overburning = FALSE;
 
- 	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_SIZE);
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_LOADING);
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_MULTISESSION);
+ 	brasero_notify_message_remove (priv->message, BRASERO_NOTIFY_CONTEXT_SIZE);
+	brasero_notify_message_remove (priv->message, BRASERO_NOTIFY_CONTEXT_LOADING);
+	brasero_notify_message_remove (priv->message, BRASERO_NOTIFY_CONTEXT_MULTISESSION);
 
 	brasero_track_data_cfg_reset (priv->project);
 }
@@ -1317,6 +1312,7 @@ brasero_data_disc_set_track (BraseroDataDisc *disc,
 {
 	BraseroMedium *loaded_medium;
 	BraseroDataDiscPrivate *priv;
+	BraseroBurnResult result;
 	BraseroStatus *status;
 	GtkWidget *message;
 	gint sort_column;
@@ -1457,34 +1453,34 @@ brasero_data_disc_set_track (BraseroDataDisc *disc,
 
 	status = brasero_status_new ();
 	brasero_track_get_status (BRASERO_TRACK (track), status);
-
-	if (brasero_status_get_result (status) == BRASERO_BURN_OK) {
+	result = brasero_status_get_result (status);
+	if (result == BRASERO_BURN_OK || result == BRASERO_BURN_RUNNING) {
 		g_object_unref (status);
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->tree), TRUE);
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->filter), TRUE);
 		return BRASERO_DISC_OK;
 	}
 
-	if (brasero_status_get_result (status) != BRASERO_BURN_NOT_READY) {
+	if (result != BRASERO_BURN_NOT_READY) {
 		g_object_unref (status);
 		return BRASERO_DISC_ERROR_UNKNOWN;
 	}
 
-	message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
+	message = brasero_notify_message_add (priv->message,
 					      _("Please wait while the project is loading."),
 					      NULL,
 					      -1,
 					      BRASERO_NOTIFY_CONTEXT_LOADING);
 
-	brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message),GTK_STOCK_DIALOG_INFO);
+	gtk_info_bar_set_message_type (GTK_INFO_BAR (message), GTK_MESSAGE_INFO);
 	brasero_disc_message_set_progress (BRASERO_DISC_MESSAGE (message),
 					   brasero_status_get_progress (status));
 
-	brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
-				   BRASERO_DISC_MESSAGE (message),
-				   _("_Cancel Loading"),
-				   _("Cancel loading current project"),
-				   GTK_RESPONSE_CANCEL);
+	gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+							      _("_Cancel Loading"),
+						    	      GTK_RESPONSE_CANCEL),
+				     _("Cancel loading current project"));
+
 	g_signal_connect (message,
 			  "response",
 			  G_CALLBACK (brasero_data_disc_message_response_cb),
@@ -1905,7 +1901,7 @@ brasero_data_disc_rename_activated (BraseroDataDisc *disc)
 
 		gtk_widget_show (frame);
 
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), frame, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), frame, TRUE, TRUE, 0);
 		gtk_widget_show (dialog);
 
 		answer = gtk_dialog_run (GTK_DIALOG (dialog));
