@@ -1,3 +1,5 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+
 /***************************************************************************
  *            brasero-layout.c
  *
@@ -242,7 +244,7 @@ brasero_layout_size_reallocate (BraseroLayout *layout)
 	BraseroLayoutObject *source;
 	GtkWidget *alignment;
 
-	alignment = layout->priv->main_box->parent;
+	alignment = gtk_widget_get_parent (layout->priv->main_box);
 
 	if (layout->priv->layout_type == BRASERO_LAYOUT_TOP
 	||  layout->priv->layout_type == BRASERO_LAYOUT_BOTTOM) {
@@ -379,6 +381,7 @@ static void
 brasero_layout_set_side_pane_visible (BraseroLayout *layout,
 				      gboolean visible)
 {
+	GtkWidget *parent;
 	gboolean preview_in_project;
 	GList *children;
 
@@ -386,6 +389,8 @@ brasero_layout_set_side_pane_visible (BraseroLayout *layout,
 	preview_in_project = (g_list_find (children, layout->priv->preview_pane) == NULL);
 	g_list_free (children);
 
+	parent = gtk_widget_get_parent (layout->priv->main_box);
+
 	if (!visible) {
 		/* No side pane should be visible */
 		if (!preview_in_project) {
@@ -404,7 +409,7 @@ brasero_layout_set_side_pane_visible (BraseroLayout *layout,
 		}
 
 		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project), NULL);
-		gtk_widget_hide (layout->priv->main_box->parent);
+		gtk_widget_hide (parent);
 	}
 	else {
 		BraseroLayoutObject *source;
@@ -433,7 +438,7 @@ brasero_layout_set_side_pane_visible (BraseroLayout *layout,
 			brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (source));
 		}
 
-		gtk_widget_show (layout->priv->main_box->parent);
+		gtk_widget_show (parent);
 	}
 
 	g_signal_emit (layout,
@@ -580,9 +585,9 @@ brasero_layout_combo_changed_cb (GtkComboBox *combo,
 		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project), NULL);
 	}
 	else {
-		brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (source));
 		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project),
 					    BRASERO_URI_CONTAINER (source));
+		brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (source));
 	}
 
 	brasero_layout_save (layout, item->id);
